@@ -65,7 +65,6 @@ class Application(Adw.Application):
         scheme_manager.prepend_search_path(get_media_path("/styles"))
 
         # Set icons
-        Gtk.Window.set_default_icon_name(self._application_id)
         Gtk.IconTheme.get_for_display(
             Gdk.Display.get_default()).add_resource_path(
             "/org/gnome/gitlab/somas/Apostrophe/icons"
@@ -79,7 +78,7 @@ class Application(Adw.Application):
         action.connect("activate", self._set_color_scheme)
         self.add_action(action)
 
-        action = Gio.SimpleAction.new("new_window", None)
+        action = Gio.SimpleAction.new("new-window", None)
         action.connect("activate", self.on_new_window)
         self.add_action(action)
 
@@ -114,7 +113,7 @@ class Application(Adw.Application):
         self.set_accels_for_action("win.find_replace", ["<Ctl>h"])
         self.set_accels_for_action("app.spellcheck", ["F7"])
 
-        self.set_accels_for_action("app.new_window", ["<Ctl>n"])
+        self.set_accels_for_action("app.new-window", ["<Ctl>n"])
         self.set_accels_for_action("app.preferences", ["<Ctl>comma"])
         self.set_accels_for_action("win.open", ["<Ctl>o"])
         self.set_accels_for_action("win.save", ["<Ctl>s"])
